@@ -1,5 +1,5 @@
 package Kephra::Config::Default::Localisation;
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 use strict;
 use warnings;
@@ -28,6 +28,7 @@ sub get {
 					edit => 'Edit',
 					edit_changes => 'History',
 					current_line => 'Line',
+					select => 'Select',
 					selection => 'Selection',
 					selection_format => 'Format',
 					selection_comment => 'Comment',
@@ -66,6 +67,7 @@ sub get {
 					view_editpanel_contexmenu => 'Edit Panel',
 					view_textmargin => 'Text Margin',
 					view_text_fold => 'Folding',
+					view_zoom => 'Zoom',
 					config => 'Config',
 					config_app_lang => 'Language',
 					config_global => 'Global Config File',
@@ -231,8 +233,8 @@ sub get {
 				},
 				select => {
 					document => 'Select All',
-					'to-block-begin' => '',
-					'to-block-end' => '',
+					toggle => 'Toggle',
+					content => 'Item',
 				},
 				search => {
 					'attribute' => {
@@ -257,7 +259,7 @@ sub get {
 					first => 'Find First',
 					last => 'Find Last',
 					selection => 'Find Selection',
-					'mark-all' => 'Mark all Matches',
+					#'mark-all' => 'Mark all Matches',
 				},
 				replace => {
 					prev => 'Replace Backward',
@@ -319,14 +321,16 @@ sub get {
 						'selection-hex' => 'Selection in Hex',
 					},
 					'choose-color' => 'Color Picker',
+					'insert-time-date' => 'Time Date',
 					perl => {
 						'insert-last-var' => 'Insert Var',
 						'copy-string' => 'Copy String',
 					},
-				},
-				document => {
 					'auto-indention' => 'Autoindention',
 					'brace-indention' => 'Braceindention',
+					'brace-completion' => 'Bracecompletion',
+				},
+				document => {
 					EOL => {
 						auto => 'Align',
 						'cr+lf' => 'CR+LF (Windows)',
@@ -430,25 +434,27 @@ sub get {
 						'this-version' => 'This Version',
 					},
 					editpanel => {
-						EOL => 'Lineend Marker',
-						'caret-line' => 'Caret Line',
-						'brace-light' => 'Bracelight',
-						'fold-toggle' => {
-							all => 'All',
-							'here' => 'Here',
-							'level' => 'Level',
-							'recursively' => 'Recursively',
-						},
-						font => 'Font',
-						'indention-guide' => 'Indention Guide',
-						'line-wrap' => 'Line Wrap',
-						'right-margin' => 'Right Margin',
-						whitespace => 'Whitespace',
 						contextmenu => {
 							custom => 'Custom',
 							default => 'Default',
 							no => 'No Menu',
 						},
+						indicator => {
+							EOL => 'Lineend Marker',
+							'brace-light' => 'Bracelight',
+							'caret-line' => 'Caret Line',
+							'indention-guide' => 'Indention Guide',
+							'right-margin' => 'Right Margin',
+							whitespace => 'Whitespace',
+						},
+						'fold-toggle' => {
+							all => 'All',
+							here => 'Here',
+							level => 'Level',
+							recursively => 'Recursively',
+						},
+						font => 'Font',
+						'line-wrap' => 'Line Wrap',
 						margin => {
 							contexmenu => 'Left Margin',
 							marker => 'Marker Margin',
@@ -492,6 +498,11 @@ sub get {
 						forum => 'Perl Forum',
 					},
 					'window-stay-on-top' => 'Stay On Top',
+					zoom => {
+						in => 'Zoom In',
+						normal => 'Normal',
+						out => 'Zoom Out',
+					},
 				},
 				config => {
 					file => {
@@ -689,8 +700,8 @@ sub get {
 				},
 				select => {
 					document => 'select entire document',
-					'to-block-begin' => '',
-					'to-block-end' => '',
+					toggle => 'toggle between selectin a word, a line, a block or nothing',
+					content => 'toggle selection between contents of braces or quotings',
 				},
 				search => {
 					attribute => {
@@ -776,14 +787,16 @@ sub get {
 						'selection-hex' => 'display selected text in hexadecimal coding in the ouput panel',
 					},
 					'choose-color' => 'display text selection as color and choose a new from a rainbow',
+					'insert-time-date' => 'insert at cursor current time and date',
 					perl => {
 						'insert-last-var' => 'insert last Perl variable that began a line',
 						'copy-string' => 'copy surrounding single or double quoted string',
 					},
+					'auto-indention' => 'indents new line like previous when Enter pressed',
+					'brace-indention' => 'autoindents one tab more after curly braces when press enter',
+					'brace-completion' => 'creates the closing brace when press enter after the opening',
 				},
 				document => {
-					'auto-indention' => 'indents new line like previous when Enter pressed',
-					'brace-indention' => 'obey right indention after curly braces when press enter',
 					EOL => {
 						auto => 'make all line endings like in first line',
 						'cr+lf' => 'line endings for Windows or Dos',
@@ -833,14 +846,14 @@ sub get {
 						java => 'Settings for Sun\'s Java language',
 						js => 'syntaxmode for Javascript',
 						latex => 'syntaxmode for the LaTeX Tex macros',
-						lisp => 'LISt Prozessor settings',
+						lisp => 'LISt Processor settings',
 						lua => 'syntaxmode for the embedding language Lua',
 						make => 'highlighting for make tool scripts',
 						matlab => 'MATLAB scripting language',
 						nsis => 'language of the Nullsoft Scriptable Install System',
 						pascal => 'Niklaus Wirth\'s structured language Pascal',
 						perl => 'syntaxmode for Larry Walls Perl',
-						php => 'Rasmus Lehrdorf PHP Hypertext Prozessors',
+						php => 'Rasmus Lehrdorf PHP Hypertext Processors',
 						property => 'Highlighting for simple config files',
 						ps => 'Adobe\'s document desciption language Postscript',
 						python => 'Guido van Rossums dynamic language Python',
@@ -887,9 +900,19 @@ sub get {
 						'this-version' => 'new features and important changes of the current version',
 					},
 					editpanel => {
-						EOL => 'switch visibility of the end of line marker',
-						'caret-line' => 'highlights row where caret(textcursor) is located',
-						'brace-light' => 'highlights associated pairs of braices',
+						contextmenu => {
+							custom => 'activate customizable editpanel context menu',
+							default => 'activate default scintilla context menu',
+							no => 'deactivate all editpanel context menu',
+						},
+						indicator => {
+							EOL => 'switch visibility of the end of line marker',
+							'brace-light' => 'highlights associated pairs of braices',
+							'caret-line' => 'highlights row where caret(textcursor) is located',
+							'indention-guide' => 'vertical dotted lines in intervals of tab width',
+							'right-margin' => 'shows straight vertical line on seleted width',
+							whitespace => 'set whitespaces and tabs visible as dots and arrows',
+						},
 						'fold-toggle' => {
 							all => 'fold or unfold all visible and not visible nodes',
 							here => 'fold or unfold only the node on selected position',
@@ -897,15 +920,7 @@ sub get {
 							recursively => 'fold or unfold this and all nodes below in hierarchy',
 						},
 						font => 'change font family, size, style etc.',
-						'indention-guide' => 'vertical dotted lines in intervals of tab width',
 						'line-wrap' => 'breaks long lines on window edge only visually',
-						'right-margin' => 'shows straight vertical line on seleted width',
-						whitespace => 'set whitespaces and tabs visible as dots and arrows',
-						contextmenu => {
-							custom => 'aktivate customizable editpanel context menu',
-							default => 'aktivate default scintilla context menu',
-							no => 'deaktivate all editpanel context menu',
-						},
 						margin => {
 							contexmenu => 'enable or disable the context menu over the margin, left of the edit panel',
 							marker => 'margin for bookmarks, marker, debug steps ...',
@@ -954,6 +969,11 @@ sub get {
 						'stay-on-top' => 'application window cant be overlapped by other windows',
 						'transparent' => 'make main window translucent',
 					},
+					zoom => {
+						in => 'make text appear larger',
+						normal => 'zoom text back to font settings',
+						out => 'make text appear smaller',
+					},
 				},
 				config => {
 					'app-lang' => 'change user interface language to',
@@ -1000,14 +1020,14 @@ sub get {
 							java => 'open settings for Sun\'s Java language',
 							js => 'open syntaxmode for Javascript',
 							latex => 'open syntaxmode for the Tex macros named LaTeX',
-							lisp => 'open settings for the almighty LISt Prozessor',
+							lisp => 'open settings for the almighty LISt Processor',
 							lua => 'settings for the extension language Lua',
 							nsis => 'language of the Nullsoft Scriptable Install System',
 							make => 'highlighting for make tool scripts',
 							matlab => 'MATLAB scripting language',
 							pascal => 'settings for Niklaus Wirth\'s procedural language Pascal',
 							perl => 'file with syntaxmode for Larry Walls Perl',
-							php => 'Rasmus Lehrdorf PHP Hypertext Prozessor',
+							php => 'Rasmus Lehrdorf PHP Hypertext Processor',
 							property => 'Highlighting for simple config files',
 							ps => 'Adobe document description language Postscript',
 							python => 'Guido van Rossums dynamic language Python',
