@@ -1,5 +1,5 @@
 package Kephra::Config::Default::MainMenu;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use strict;
 use warnings;
@@ -8,30 +8,30 @@ sub get {
 	return [
 		{'menu file' => [
 			'item file-new',
-			undef ,
+			undef,
 			{'menu file_open file-open' => [
 				'item file-open',
 				'item file-open-dir',
-				undef ,
+				undef,
 				'item file-insert',
-				undef ,
+				undef,
 				'item file-reload',
 				'item file-reload-all',
 			],},
 			'menu file_history',
-			undef ,
+			undef,
 			{'menu file_session' => [
 				'item file-session-open',
 				'item file-session-add',
 				'item file-session-save',
-				undef ,
+				undef,
 				'item file-session-backup-open',
 				'item file-session-backup-save',
-				undef ,
+				undef,
 				'item file-session-import',
 				'item file-session-export',
 			],},
-			undef ,
+			undef,
 			'item file-save-current',
 			#'menu file_save' => []
 			'item file-save-all',
@@ -39,17 +39,17 @@ sub get {
 			'item file-save-copy-as',
 			'item file-rename',
 			#'item file-print',
-			undef ,
+			undef,
 			{'menu file_close file-close-current' => [
 				'item file-close-current',
 				'item file-close-other',
 				'item file-close-all',
-				undef ,
+				undef,
 				'item file-close-unsaved',
 				'item file-close-other-unsaved',
 				'item file-close-all-unsaved',
 			],},
-			undef ,
+			undef,
 			'item app-exit-unsaved',
 			'item app-exit',
 		],},
@@ -59,28 +59,19 @@ sub get {
 			{'menu edit_changes' => [
 				'item edit-changes-undo-several',
 				'item edit-changes-redo-several',
-				undef ,
+				undef,
 				'item edit-changes-goto-begin',
 				'item edit-changes-goto-end',
-				undef ,
+				undef,
 				'item edit-changes-delete',
 			],},
-			undef ,
+			undef,
 			'item edit-cut',
 			'item edit-copy',
 			'item edit-paste',
 			'item edit-replace',
 			'item edit-delete',
-			undef ,
-			'item select-document',
-			{'menu selection' => [
-				'item edit-selection-move-char-left',
-				'item edit-selection-move-char-right',
-				'item edit-selection-move-line-up',
-				'item edit-selection-move-line-down',
-				'item edit-selection-move-page-up',
-				'item edit-selection-move-page-down',
-			],},
+			undef,
 			{'menu current_line' => [
 				'item edit-line-cut',
 				'item edit-line-copy',
@@ -90,38 +81,51 @@ sub get {
 				'item edit-line-delete',
 				'item edit-line-delete-left',
 				'item edit-line-delete-right',
-				undef ,
+				undef,
 				'item edit-line-move-line-up',
 				'item edit-line-move-line-down',
 				'item edit-line-move-page-up',
 				'item edit-line-move-page-down',
 			],},
+			{'menu select' => [
+				'item select-toggle',
+				'item select-content',
+				'item select-document',
+			],},
+			{'menu selection' => [
+				'item edit-selection-move-char-left',
+				'item edit-selection-move-char-right',
+				'item edit-selection-move-line-up',
+				'item edit-selection-move-line-down',
+				'item edit-selection-move-page-up',
+				'item edit-selection-move-page-down',
+			],},
 			#'menu navigation' => [,
-			undef ,
+			undef,
 			{'menu selection_format' => [
 				'item edit-selection-format-indent-char',
 				'item edit-selection-format-dedent-char',
 				'item edit-selection-format-indent-tab',
 				'item edit-selection-format-dedent-tab',
 				'item edit-selection-format-align-on-begin',
-				undef ,
+				undef,
 				'item edit-selection-format-join-lines',
-				undef ,
+				undef,
 				'item edit-selection-format-block-on-right-margin',
 				'item edit-selection-format-block-on-width',
 				'item edit-selection-format-linewrap-on-right-margin',
 				'item edit-selection-format-linewrap-on-width',
-				undef ,
+				undef,
 				'item edit-selection-format-del-trailing-whitespace',
 			],},
 			{'menu selection_comment' => [
 				'item edit-selection-comment-add-perl',
 				'item edit-selection-comment-del-perl',
 				'item edit-selection-comment-toggle-perl',
-				undef ,
+				undef,
 				'item edit-selection-comment-add-c',
 				'item edit-selection-comment-del-c',
-				undef ,
+				undef,
 				'item edit-selection-comment-add-xml',
 				'item edit-selection-comment-del-xml',
 			],},
@@ -130,10 +134,10 @@ sub get {
 				'item edit-selection-convert-lowercase',
 				'item edit-selection-convert-titlecase',
 				'item edit-selection-convert-sentencecase',
-				undef ,
+				undef,
 				'item edit-selection-convert-spaces2tabs',
 				'item edit-selection-convert-tabs2spaces',
-				undef ,
+				undef,
 				'item edit-selection-convert-spaces2entities',
 				'item edit-selection-convert-entities2spaces',
 				'item edit-selection-convert-chars2entities',
@@ -161,20 +165,20 @@ sub get {
 			{'menu search_attributes' => [
 				'checkitem search-attribute-incremental-switch',
 				'checkitem search-attribute-autowrap-switch',
-				undef ,
+				undef,
 				'checkitem search-attribute-regex-switch',
 				'checkitem search-attribute-match-whole-word-switch',
 				'checkitem search-attribute-match-word-begin-switch',
 				'checkitem search-attribute-match-case-switch',
-				undef ,
+				undef,
 				'radioitem search-range-selection',
 				'radioitem search-range-document',
 				'radioitem search-range-open-docs',
 			],},
-			undef ,
+			undef,
 			'item goto-line',
 			'item goto-last-edit',
-			undef ,
+			undef,
 			{'menu marker' => [
 				'item marker-goto-prev-doc',
 				'item marker-goto-next-doc',
@@ -184,7 +188,7 @@ sub get {
 				'item marker-delete-doc',
 				'item marker-delete-all',
 			],},
-			undef ,
+			undef,
 			{'menu bookmark_goto' => [
 				'item bookmark-goto-1',
 				'item bookmark-goto-2',
@@ -213,40 +217,44 @@ sub get {
 			'item bookmark-delete-all',
 		],},
 		{'menu tools' => [
-			'item tool-note',
-			'item tool-note-selection',
-			undef ,
+			'item tool-interpreter-run-document',
+			'item tool-interpreter-stop-document',
 			{'menu tool_output' => [
 				'item tool-output-selection-dec',
 				'item tool-output-selection-hex',
-				undef ,
+				undef,
 				'item tool-output-env',
 				'item tool-output-inc',
 			],},
-			'item tool-interpreter-run-document',
-			'item tool-interpreter-stop-document',
-			undef ,
+			undef,
 			'menu insert_templates',
 			'item tool-choose-color',
 			'item tool-insert-time-date',
-			undef ,
+			undef,
 			'item tool-perl-insert-last-var',
 			'item tool-perl-copy-string',
+			undef,
+			'item tool-note',
+			'item tool-note-selection',
+			undef,
+			'checkitem tool-auto-indention',
+			'checkitem tool-brace-indention',
+			'checkitem tool-brace-completion',
 		],},
 		{'menu document' => [
 			{'menu document_change' => [
 				'item document-change-prev',
 				'item document-change-next',
 				'item document-change-back',
-				undef ,
+				undef,
 				'item document-move-right',
 				'item document-move-left',
 			],},
-			undef ,
+			undef,
 			{'menu document_syntaxmode' => [
 				'item document-syntaxmode-auto',
 				'checkitem document-syntaxmode-none',
-				undef ,
+				undef,
 				{'menu document_syntaxmode_A-M' => [
 					'checkitem document-syntaxmode-ada',
 					'checkitem document-syntaxmode-as',
@@ -293,7 +301,7 @@ sub get {
 					'checkitem document-syntaxmode-xml',
 					'checkitem document-syntaxmode-yaml',
 				],},
-				undef ,
+				undef,
 				{'menu document_syntaxmode_compiled' => [
 					'checkitem document-syntaxmode-asm',
 					'checkitem document-syntaxmode-c',
@@ -359,8 +367,6 @@ sub get {
 				#'radioitem document-encoding-latin1',
 				'radioitem document-encoding-utf8',
 			],},
-			'checkitem document-brace-indention',
-			'checkitem document-auto-indention',
 			'checkitem document-tabs-use',
 			{'menu document_tab_width' => [
 				'radioitem document-tabs-width-1',
@@ -390,8 +396,8 @@ sub get {
 				'checkitem view-window-transparent',
 			],},
 			{'menu view_panel' => [
-				'checkitem view-panel-notepad',
 				'checkitem view-panel-output',
+				'checkitem view-panel-notepad',
 			],},
 			{'menu view_bars' => [
 				'checkitem view-menubar',
@@ -411,7 +417,7 @@ sub get {
 				'checkitem view-searchbar-contexmenu',
 				'checkitem view-statusbar-contexmenu',
 			],},
-			undef ,
+			undef,
 			'checkitem view-editpanel-margin-marker',
 			'checkitem view-editpanel-margin-line-number',
 			'checkitem view-editpanel-margin-text-fold',
@@ -432,30 +438,35 @@ sub get {
 				'radioitem view-editpanel-margin-text-10',
 				'radioitem view-editpanel-margin-text-12',
 			],},
-			undef ,
+			undef,
 			'checkitem view-editpanel-right-margin',
-			'checkitem view-editpanel-indention-guide',
-			'checkitem view-editpanel-brace-light',
-			'checkitem view-editpanel-caret-line',
 			'checkitem view-editpanel-line-wrap',
-			'checkitem view-editpanel-EOL',
-			'checkitem view-editpanel-whitespace',
+			'checkitem view-editpanel-indicator-indention-guide',
+			'checkitem view-editpanel-indicator-brace-light',
+			'checkitem view-editpanel-indicator-caret-line',
+			'checkitem view-editpanel-indicator-EOL',
+			'checkitem view-editpanel-indicator-whitespace',
 			'item view-editpanel-font',
+			{'menu view_zoom' => [
+				'item view-editpanel-zoom-in',
+				'item view-editpanel-zoom-out',
+				'item view-editpanel-zoom-normal',
+			],},
 		],},
 		{'menu config' => [
 			'item view-dialog-config',
-			undef ,
+			undef,
 			'menu config_app_lang',
-			undef ,
+			undef,
 			{'menu config_global' => [
 				'item config-file-global-open',
 				'item config-file-global-reload',
 				'item config-file-global-save',
-				undef ,
+				undef,
 				'item config-file-global-load-from',
 				'item config-file-global-merge',
 				'item config-file-global-save-as',
-				undef ,
+				undef,
 				'item config-file-global-load-backup',
 				'item config-file-global-load-defaults',
 			],},
@@ -524,12 +535,12 @@ sub get {
 			'item view-documentation-feature-list',
 			'item view-documentation-advanced-tour',
 			'item view-documentation-credits',
-			undef ,
+			undef,
 			'item view-webpage-documentation',
 			'item view-webpage-forum',
 			'item view-webpage-bug-tracker',
 			'item view-webpage-feature-wish',
-			undef ,
+			undef,
 			'item view-dialog-keymap',
 			'item view-dialog-info',
 		],},
